@@ -198,7 +198,10 @@ def load_data_from_file(
             wait_for_job(job)
         except Exception as e:
             shutil.copyfile(csv_file.name, "/tmp/error.csv")
-            extra_info = '. Failed CSV has been copied to /tmp/error.csv'
+            extra_info = '. Failed CSV has been copied to /tmp/error.csv; '
+            extra_info += "final line:\n"
+            extra_info += subprocess.check_output(
+                'tail -1 /tmp/error.csv', shell=True)
             e.args = (e.args[0] + extra_info,), e.args[1:]
             raise
         return job
